import logging
from kapybara import WebDriver, shared_data
from kapybara.form_element import FormElement
from phis_login.gui_error import gui_error
from phis_login.登录医生工作站 import 登录医生工作站
from phis_config import AdminConfig


def 登录健康档案系统():
    url = AdminConfig.登录网址
    account = AdminConfig.登录用户名
    password = AdminConfig.登录密码
    department_name = AdminConfig.登录科室名称
    name = department_name

    driver: WebDriver = shared_data.driver

    # 设置登录超时
    driver.set_page_load_timeout(600)
    try:
        driver.get(url)
    except:
        try:
            driver.get(url)
        except:
            error_message = '登录页面加载失败，请检查URL是否正确或网络连接是否正常。'
            logging.error(error_message)
            gui_error(error_message)

            driver.quit()
            exit(-1)

    driver.maximize_window()

    登录医生工作站(account, password)

    FormElement('健康档案', '//*[@id="ext-gen3"]/section/div[3]/ul/li[1]/a').click()
    # 关闭 “系统提示” 对话框
    FormElement('确定', '//*[@id="button-1005-btnIconEl"]').click()
    # 点击慢病随访
    FormElement('档案管理', 'navLi_10103').click()



import logging

import ddddocr
from pathlib import Path
from kapybara.form_element import FormElement
from kapybara import shared_data, WebDriver
from phis_login.gui_error import gui_error

retry_count = 0


def 登录医生工作站(username: str, password: str):
    """
    输入用户名和密码并点击登录
    """
    global retry_count
    FormElement('用户名', 'phisname').set_value(username)
    FormElement('密码', 'password').set_value(password)

    captcha_element = FormElement('验证码', 'img')
    captcha_element.element.screenshot('captcha.png')

    ocr = ddddocr.DdddOcr()
    img_bytes = Path('captcha.png').read_bytes()
    res = ocr.classification(img_bytes)
    logging.info('识别出的验证码为：' + res)
    FormElement('验证码输入', 'verifyCode').set_value(res)
    try:
        FormElement('登录', '.submit-btn').click()
    except:
        logging.info('无需点击登录')

    import time

    time.sleep(1)  # 等待页面加载
    driver: WebDriver = shared_data.driver
    current_url = driver.current_url
    if 'phis/app/login' in current_url:
        retry_count += 1
        if retry_count < 3:
            logging.warning(f'登录失败，正在重试... ({retry_count}/3)')
            登录医生工作站(username, password)
        else:
            error_message = '登录失败，请检查用户名、密码或验证码是否正确。'
            logging.error(error_message)
            gui_error(error_message)
            raise Exception(error_message)
